using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.Common;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using iAnywhere.Data.UltraLite;

namespace SchemaUpgrade
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void UpdateDisplay()
        {

            String SchemaVersionText;
            DataAccess.DataAccess da = DataAccess.DataAccess.Instance;
            Int32 schemaVersion = da.CurrentSchemaVersion();
            if (schemaVersion == 0)
            {
                btnSyncData.Enabled = false;
                SchemaVersionText = "Schema version is not set.";
            }
            else
            {
                btnSyncData.Enabled = true;
                SchemaVersionText = "Using schema " + schemaVersion + ".";
            }
            if (!da.IsSchemaUpgradeComplete())
            {
                SchemaVersionText += " Schema upgrade has been downloaded.";
            }
            txtSchemaVersion.Text = SchemaVersionText;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            UpdateDisplay();
        }

        private void btnSyncData_Click(object sender, EventArgs e)
        {
            Int32 CurrentVersion;
            using (DataAccess.DataAccess da = DataAccess.DataAccess.Instance)
            {
                CurrentVersion = da.CurrentSchemaVersion();
                String publication = "";
                publication = "PublicationData";
                da.Synchronize(publication, CurrentVersion.ToString());
                try
                {
                    using (DbDataReader dr = da.EmployeeResultSet())
                    {
                        lbEmployeeID.Items.Clear();
                        lbEmployeeName.Items.Clear();
                        lbEmployeePhone.Items.Clear();
                        lbEmployeeEMail.Items.Clear();

                        while (dr.Read())
                        {
                            lbEmployeeID.Items.Add(dr.GetInt32(0));
                            lbEmployeeName.Items.Add(dr.GetString(1));
                            if (CurrentVersion >= 2)
                            {
                                lbEmployeePhone.Items.Add(dr.GetString(2));
                            }
                            if (CurrentVersion >= 3)
                            {
                                lbEmployeeEMail.Items.Add(dr.GetString(3));
                            }
                        }
                    }
                }
                catch (DbException dbex)
                {
                    MessageBox.Show(dbex.Message);
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString() + ": " + ex.Message);
                }
            }
        }

        private void btnSyncSchema_Click(object sender, EventArgs e)
        {
            DataAccess.DataAccess da = DataAccess.DataAccess.Instance;
            if (da.Synchronize("PublicationSchema", "VersionSchema"))
            {
                if (da.UpgradeSchema())
                {
                    // Sync to say that the upgrade succeeded
                    da.Synchronize("PublicationSchema", "VersionSchema");
                }
            }
            UpdateDisplay();
        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }
    }
}